<?php
/*
Plugin Name: Quotables
plugin URI: https://99robots.com/products/quotables/
Description: The Quotables plugin gives you an easy way to add a beautiful actionable share links to your sidebar in your post content.
version: 1.1.6
Author: 99 Robots
Author URI: http://99robots.com
License: GPL2
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Global Definitions
 */

/* Item Name */

if (!defined('NNROBOTS_QUOTABLES_ITEM_NAME'))
    define('NNROBOTS_QUOTABLES_ITEM_NAME', 'Quotables');

/* Store URL */

if (!defined('NNROBOTS_QUOTABLES_STORE_URL'))
    define('NNROBOTS_QUOTABLES_STORE_URL', 'https://99robots.com');

/* Minimum PHP version */

if (!defined('NNROBOTS_QUOTABLES_MIN_PHP_VERSION'))
    define('NNROBOTS_QUOTABLES_MIN_PHP_VERSION', '5.4.0');

/* Plugin Name */

if (!defined('NNROBOTS_QUOTABLES_PLUGIN_NAME'))
    define('NNROBOTS_QUOTABLES_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));

/* Plugin directory */

if (!defined('NNROBOTS_QUOTABLES_PLUGIN_DIR'))
    define('NNROBOTS_QUOTABLES_PLUGIN_DIR', plugin_dir_path(__FILE__) );

/* Plugin url */

if (!defined('NNROBOTS_QUOTABLES_PLUGIN_URL'))
    define('NNROBOTS_QUOTABLES_PLUGIN_URL', plugins_url() . '/' . NNROBOTS_QUOTABLES_PLUGIN_NAME);

/* Plugin verison */

if (!defined('NNROBOTS_QUOTABLES_VERSION_NUM'))
    define('NNROBOTS_QUOTABLES_VERSION_NUM', '1.1.6');

// Include files

require_once('admin/functions.php');
require_once('shortcode.php');

// Hooks / Filters

add_shortcode('nnr_quotables', 									'nnr_quotables_shortcode');
register_activation_hook( __FILE__, 							array('NNRobots_Quotables', 'register_activation'));
add_action( 'init', 											array('NNRobots_Quotables', 'load_textdomain'));
add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array('NNRobots_Quotables', 'settings_link'));
add_action( 'admin_menu', 										array('NNRobots_Quotables', 'menu_page'));

// Register the Widget

add_action( 'widgets_init', function(){
     register_widget( 'NNRobots_Quotables' );
});

// Software Licensing Updates

add_action('wp_ajax_nnr_q_license_action', array('NNRobots_Quotables', 'license_action'));

if ( !class_exists('EDD_SL_Plugin_Updater') ) {
	include_once( dirname( __FILE__ ) . '/admin/include/edd-software-licensing-updates/EDD_SL_Plugin_Updater.php' );
}

$edd_updater = new EDD_SL_Plugin_Updater( NNROBOTS_QUOTABLES_STORE_URL , __FILE__, array(
		'version' 	=> NNROBOTS_QUOTABLES_VERSION_NUM,
		'license' 	=> NNRobots_Quotables::get_license_key(),
		'item_name' => NNROBOTS_QUOTABLES_ITEM_NAME,
		'author' 	=> '99 Robots',
	)
);

/**
 *  NNRobots_Quotables main class
 *
 * @since 1.0.0
 * @using Wordpress 3.8
 */

class NNRobots_Quotables extends WP_Widget {

	/**
	 * text_domain
	 *
	 * (default value: 'quotables')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $text_domain = 'quotables';

	/**
	 * prefix
	 *
	 * (default value: 'nnrobots_quotables_')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix = 'nnrobots_quotables_';

	/**
	 * base_id
	 *
	 * (default value: 'nnrobots_quotables_')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $base_id = 'nnrobots_quotables';

	/**
	 * prefix_dash
	 *
	 * (default value: 'nnr-q-')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix_dash = 'nnr-q-';

	/**
	 * settings_page
	 *
	 * (default value: 'nnrobots-quotables-settings')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $settings_page = 'nnrobots-quotables-settings';

	/**
	 * default
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $default = array(
		'bitly' 			=> '',
		'twitter_username'	=> '99robots',
	);

	/**
	 * default_widget
	 *
	 * @var mixed
	 * @access public
	 * @static
	 */
	static $default_widget = array(
		'text'					=> 'Share this Article!',
		'platform'				=> 'twitter',
		'layout'				=> 'box',
		'style'					=> 'color',
		'bitly'					=> '',
		'button_text'			=> 'Share',
		'twitter_username'		=> '',
	);

	/**
	 * Load the text domain
	 *
	 * @since 1.0.0
	 */
	static function load_textdomain() {
		load_plugin_textdomain(self::$text_domain, false, NNROBOTS_QUOTABLES_PLUGIN_DIR . '/languages');
	}

	/**
	 * Hooks to 'register_activation_hook'
	 *
	 * @since 1.0.0
	 */
	static function register_activation() {

		/* Check if multisite, if so then save as site option */

		if (function_exists("is_multisite") && is_multisite()) {
			add_site_option(self::$prefix . 'version', NNROBOTS_QUOTABLES_VERSION_NUM);
		} else {
			add_option(self::$prefix . 'version', NNROBOTS_QUOTABLES_VERSION_NUM);
		}
	}

	/**
	 * Hooks to 'plugin_action_links_' filter
	 *
	 * @since 1.0.0
	 */
	static function settings_link($links) {

		$widget_link = '<a href="widgets.php">' . __('Widget', self::$text_domain) . '</a>';
		array_unshift($links, $widget_link);

		$settings_link = '<a href="options-general.php?page=' . self::$settings_page . '">' . __('Settings', self::$text_domain) . '</a>';
		array_unshift($links, $settings_link);

		return $links;
	}

	/**
	 * Perform all the actions with a license
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function license_action() {

		if ( !isset($_POST['license_key']) ) {
			echo '';
			die();
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> $_POST['license_action'],
			'license' 		=> $_POST['license_key'],
			'item_name' 	=> urlencode( NNROBOTS_QUOTABLES_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_QUOTABLES_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			echo $response;
			die();
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		if ( $_POST['license_action'] == 'activate_license' ) {
			self::update_license_key($_POST['license_key']);
		} else if ( $_POST['license_action'] == 'deactivate_license' && $license_data->license == 'deactivated') {
			self::update_license_key('');
		}

		// decode the license data

		echo $license_data->license;

		die();

	}

	/**
	 * Check if license key is active
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function is_license_active( $license_key ) {

		if ( !isset( $license_key ) ) {
			return false;
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> 'check_license',
			'license' 		=> $license_key,
			'item_name' 	=> urlencode( NNROBOTS_QUOTABLES_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_QUOTABLES_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// decode the license data

		if ( isset($license_data->license) && $license_data->license == 'valid' ) {
			return true;
		} else {
			return false;
		}

	}

	/**
	 * Get the license key
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function get_license_key() {

		// Get the license key from based on WordPress install

		if ( function_exists('is_multisite') && is_multisite() ) {
			$license_key = get_site_option(self::$prefix . 'license_key');
		} else {
			$license_key = get_option(self::$prefix . 'license_key');
		}

		// Check if license key is set

		if ( $license_key === false ) {
			$license_key = '';
		}

		return $license_key;
	}

	/**
	 * Update the license key
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function update_license_key($license_key) {

		if ( isset( $license_key ) ) {

			// Get the license key from based on WordPress install

			if ( function_exists('is_multisite') && is_multisite() ) {

				update_site_option(self::$prefix . 'license_key', $license_key);

			} else {

				update_option(self::$prefix . 'license_key', $license_key);

			}
		}
	}

	/**
	 * Hooks to 'admin_menu'
	 *
	 * @since 1.0.0
	 */
	static function menu_page() {

	    // Cast the first sub menu to the top menu

	    $settings_page_load = add_submenu_page(
	    	'options-general.php', 										// parent slug
	    	__('Quotables', self::$text_domain), 						// Page title
	    	__('Quotables', self::$text_domain), 						// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$settings_page, 										// slug
	    	array('NNRobots_Quotables', 'admin_settings')				// Callback function
	    );
	    add_action("admin_print_scripts-$settings_page_load", array('NNRobots_Quotables', 'include_admin_scripts'));
	}

	/**
	 * Hooks to 'admin_print_scripts-$page'
	 *
	 * @since 1.0.0
	 */
	static function include_admin_scripts() {

		wp_enqueue_style(self::$prefix . 'admin_css', 				NNROBOTS_QUOTABLES_PLUGIN_URL . '/admin/css/settings.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_css', 			NNROBOTS_QUOTABLES_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
		wp_enqueue_style(self::$prefix_dash . 'fontawesome_css',	NNROBOTS_QUOTABLES_PLUGIN_URL . '/admin/include/fontawesome/css/font-awesome.min.css');

		wp_enqueue_script('jquery');
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 			NNROBOTS_QUOTABLES_PLUGIN_URL . '/admin/js/bootstrap.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'settings_js', 			NNROBOTS_QUOTABLES_PLUGIN_URL . '/admin/js/settings.js', array('jquery'));
		wp_localize_script(self::$prefix . 'settings_js', 		'nnr_q_data', array(
			'prefix_dash'			=> self::$prefix_dash,
			'activate_text'			=> __('Activate', self::$text_domain),
			'deactivate_text'		=> __('Deactivate', self::$text_domain),
			'no_license_key'		=> __('Please add or activate your License Key to get automatic updates.  Without a valid license key you will not receive regular updates. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'expired'				=> __('EXPIRED: This license key has expired.  Please renew your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'activation_error'		=> __('INVALID LICENSE KEY: The license key is not valid please try again. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>.',
			'activation_valid'		=> __('SUCCESS: Your license key is valid.', self::$text_domain),
			'deactivation_valid'	=> __('SUCCESS: This site has been deactivated.', self::$text_domain),
			'deactivation_error'	=> __('DEACTIVATION FAILED: This site could not be deactivated.', self::$text_domain),
		));
	}

	/**
	 * Displays the HTML for the 'nnrobots-popular-posts-admin-menu-settings' admin page
	 *
	 * @since 1.0.0
	 */
	static function admin_settings() {

		global $wp_version;

		$license_key = self::get_license_key();

		require('admin/controllers/settings.php');
	}

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			self::$base_id,
			__( 'Quotables', self::$text_domain ),
			array( 'description' => __( 'Beautiful way to display an actionable share link.', self::$text_domain ), )
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		// Do not display if not a single post

		if ( !is_singular() ) {
			return false;
		}

		$settings = get_option(self::$prefix . 'settings');

		// Default values

		if ($settings === false) {
			$settings = self::$default;
		}

		global $post;

		echo $args['before_widget'];

		// Set the default values

		if ( empty( $instance ) ) {
			$instance = NNRobots_Quotables::$default_widget;
		}

		// Title

		if ( empty( $instance['title'] ) ) {
			$instance['title'] = __( 'Share this article!', self::$text_domain );
		}

		// Bitly access token

		if ( !empty( $settings['bitly'] ) && $settings['bitly'] != '' ) {
			$instance['title'] = __( 'Share this article!', self::$text_domain );

			$ch = curl_init();
			curl_setopt ($ch, CURLOPT_URL, 'https://api-ssl.bitly.com/v3/shorten?access_token=' . $settings['bitly'] . '&longUrl=' . urlencode(get_site_url() . '?p=' . $post->ID) . '&format=json');
			curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
			$result = curl_exec($ch);
			curl_close($ch);

			if (isset(json_decode($result)->data->url)) {
				$post_link = json_decode($result)->data->url;
			}
		}

		if ( !isset($post_link) || empty($post_link) ) {
			$post_link = get_site_url() . '?p=' . $post->ID;
		}

		// Button Text

		if ( empty( $instance['button_text'] ) ) {
			$instance['button_text'] = __( 'Share', self::$text_domain );
		}

		// Get the featured image

		$featured_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');

		if ( $featured_image ) {
			$featured_image = $featured_image[0];
		}

		if ( $instance['platform'] != 'pinterest' || ( $instance['platform'] == 'pinterest' && $featured_image ) ) {

			?>
			<div class="<?php echo self::$prefix_dash; ?>widget <?php echo self::$prefix_dash; ?>container <?php echo self::$prefix_dash; ?>container-<?php echo $instance['platform']; ?> <?php echo self::$prefix_dash; ?>style-<?php echo $instance['style']; ?>">

				<div class="<?php echo self::$prefix_dash; ?>title-container">
					<span aria-hidden="true" class="<?php echo self::$prefix_dash; ?>icon <?php echo self::$prefix_dash; ?>icon-<?php echo $instance['platform']; ?>"></span>
					<span class="<?php echo self::$prefix_dash; ?>title"><?php echo $instance['title']; ?></span>
				</div>

				<div class="<?php echo self::$prefix_dash; ?>text-container">
					<p class="<?php echo self::$prefix_dash; ?>post-title"><?php echo $post->post_title; ?></p>
					<p class="<?php echo self::$prefix_dash; ?>quote-container">
						<span class="<?php echo self::$prefix_dash; ?>quote"></span>
					</p>
				</div>

				<?php if ( $instance['platform'] == 'twitter' ) {

					$twitter_intent = 'https://twitter.com/intent/tweet?text=' .  mb_substr( htmlentities($post->post_title . ' ' . $post_link), 0, 138 );

					if ( isset($instance['twitter_username']) && $instance['twitter_username'] != '' ) {
						$twitter_intent .= '&via=' . htmlentities($instance['twitter_username']);
					}?>

					<a class="<?php echo self::$prefix_dash; ?>button" href="<?php echo $twitter_intent; ?>" target="_blank">
					<?php echo $instance['button_text']; ?>
				</a>
				<?php } ?>

				<?php if ( $instance['platform'] == 'facebook' ) { ?>
					<a class="<?php echo self::$prefix_dash; ?>button" href="https://www.facebook.com/sharer/sharer.php?u=<?php echo htmlentities($post_link); ?>" target="_blank">
					<?php echo $instance['button_text']; ?>
				</a>
				<?php } ?>

				<?php if ( $instance['platform'] == 'google' ) { ?>
					<a class="<?php echo self::$prefix_dash; ?>button" href="https://plus.google.com/share?url=<?php echo htmlentities($post_link); ?>" target="_blank">
					<?php echo $instance['button_text']; ?>
				</a>
				<?php } ?>

				<?php if ( $instance['platform'] == 'pinterest' ) { ?>
					<a class="<?php echo self::$prefix_dash; ?>button" href="https://www.pinterest.com/pin/create/button/?url=<?php echo htmlentities($post_link); ?>&media=<?php echo $featured_image; ?>&description=<?php echo htmlentities($post->post_title); ?>" target="_blank">
					<?php echo $instance['button_text']; ?>
				</a>
				<?php } ?>

				<?php if ( $instance['platform'] == 'tumblr' ) { ?>
					<a class="<?php echo self::$prefix_dash; ?>button" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo htmlentities($post_link); ?>" target="_blank">
					<?php echo $instance['button_text']; ?>
				</a>
				<?php } ?>

				<?php if ( $instance['platform'] == 'linkedin' ) { ?>
					<a class="<?php echo self::$prefix_dash; ?>button" href="https://www.linkedin.com/shareArticle?url=<?php echo htmlentities($post_link); ?>&title=<?php echo htmlentities($post->post_title); ?>" target="_blank">
					<?php echo $instance['button_text']; ?>
				</a>
				<?php } ?>

			</div>
			<?php

		}

		wp_enqueue_style( self::$prefix . 'css', NNROBOTS_QUOTABLES_PLUGIN_URL . '/core/css/quotables.css');

		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {

		/**
		 * title
		 *
		 * (default value: Share this article!)
		 *
		 * @var string
		 * @access public
		 */
		$title = 	! empty( $instance['title'] ) ?
					$instance['title'] :
					__( 'Share this article!', self::$text_domain );

		/**
		 * platform
		 *
		 * (default value: 'twitter')
		 *
		 * @var mixed
		 * @access public
		 */
		$platform = ! empty( $instance['platform'] ) ?
					$instance['platform'] :
					'twitter';

		/**
		 * style
		 *
		 * (default value: 'color')
		 *
		 * @var mixed
		 * @access public
		 */
		$style = 	! empty( $instance['style'] ) ?
					$instance['style'] :
					'color';

		/**
		 * button_text
		 *
		 * (default value: Share)
		 *
		 * @var string
		 * @access public
		 */
		$button_text = 	! empty( $instance['button_text'] ) ?
						$instance['button_text'] :
						__( 'Share', self::$text_domain );

		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', self::$text_domain ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>"><br/>
			<em><?php _e( 'The title of the widget.', self::$text_domain ); ?></em>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'platform' ); ?>"><?php _e( 'Platform:', self::$text_domain ); ?></label>
			<select id="<?php echo $this->get_field_id( 'platform' ); ?>" name="<?php echo $this->get_field_name( 'platform' ); ?>" class="<?php echo $this->id; ?>platform-type">
				<option value="twitter" <?php selected('twitter', $platform, true); ?>><?php _e( 'Twitter', self::$text_domain ); ?></option>
				<option value="facebook" <?php selected('facebook', $platform, true); ?>><?php _e( 'Facebook', self::$text_domain ); ?></option>
				<option value="google" <?php selected('google', $platform, true); ?>><?php _e( 'Google+', self::$text_domain ); ?></option>
				<option value="pinterest" <?php selected('pinterest', $platform, true); ?>><?php _e( 'Pinterest', self::$text_domain ); ?></option>
				<option value="tumblr" <?php selected('tumblr', $platform, true); ?>><?php _e( 'Tumblr', self::$text_domain ); ?></option>
				<option value="linkedin" <?php selected('linkedin', $platform, true); ?>><?php _e( 'LinkedIn', self::$text_domain ); ?></option>
			</select><br/>
			<em><?php _e( 'Which platform you want to display the share link for.', self::$text_domain ); ?></em>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'style' ); ?>"><?php _e( 'Style:', self::$text_domain ); ?></label>
			<select id="<?php echo $this->get_field_id( 'style' ); ?>" name="<?php echo $this->get_field_name( 'style' ); ?>">
				<option value="color" <?php selected('color', $style, true); ?>><?php _e( 'Color', self::$text_domain ); ?></option>
				<option value="light" <?php selected('light', $style, true); ?>><?php _e( 'Light', self::$text_domain ); ?></option>
				<option value="dark" <?php selected('dark', $style, true); ?>><?php _e( 'Dark', self::$text_domain ); ?></option>
			</select><br/>
			<em><?php _e( 'The style of the widget box.', self::$text_domain ); ?></em>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button_text' ); ?>"><?php _e( 'Button Text:', self::$text_domain ); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'button_text' ); ?>" name="<?php echo $this->get_field_name( 'button_text' ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>"><br/>
			<em><?php _e( 'The text of the share button.', self::$text_domain ); ?></em>
		</p>

		<script type="text/javascript">
			jQuery(document).ready(function($){

				var prefix = "<?php echo $this->id; ?>";

				// Hide and show shortcode settings

				$('.' + prefix + 'platform').hide();
				$('.' + prefix + 'platform-' + $('.' + prefix + 'platform-type').val()).show();

				$('.' + prefix + 'platform-type').change(function(){
					$('.' + prefix + 'platform').hide();
					$('.' + prefix + 'platform-' + $('.' + prefix + 'platform-type').val()).show();
				});
			});
		</script>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['platform'] = ( ! empty( $new_instance['platform'] ) ) ? strip_tags( $new_instance['platform'] ) : 'twitter';
		$instance['style'] = ( ! empty( $new_instance['style'] ) ) ? strip_tags( $new_instance['style'] ) : 'color';
		$instance['button_text'] = ( ! empty( $new_instance['button_text'] ) ) ? strip_tags( $new_instance['button_text'] ) : '';

		return $instance;
	}
}
